==> tgp_1.1-9.tar.gz: tgp/demo/as.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(maptree)
graphics.off()


###################################################
### chunk number 2: 
###################################################
exp2d.data <- exp2d.rand()
X <- exp2d.data$X; Z <- exp2d.data$Z
Xcand <- exp2d.data$XX


###################################################
### chunk number 3: 
###################################################
exp1 <- btgpllm(X=X, Z=Z, pred.n=FALSE, corr="exp")


###################################################
### chunk number 4: mapt
###################################################
tgp.trees(exp1)


###################################################
### chunk number 5: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 6: 
###################################################
XX <- tgp.design(10, Xcand, exp1)


###################################################
### chunk number 7: cands
###################################################
plot(exp1$X, pch=19, cex=0.5); points(XX)
tgp.plot.parts.2d(exp1$parts)


###################################################
### chunk number 8: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 9: 
###################################################
exp1.btgpllm <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", ego=TRUE, ds2x=TRUE)


###################################################
### chunk number 10: expalm
###################################################
par(mfrow=c(1,2), bty="n")
plot(exp1.btgpllm, main="treed GP LLM,", method="akima", layout="surf")
plot(exp1.btgpllm, main="treed GP LLM,", method="akima", layout="as", as="alm")


###################################################
### chunk number 11: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 12: expalcego
###################################################
par(mfrow=c(1,2), bty="n")
plot(exp1.btgpllm, main="treed GP LLM,", method="akima", layout='as', as='alc')
plot(exp1.btgpllm, main="treed GP LLM,", method="akima", layout='as', as='ego')

==> tgp_2.0.tar.gz: tgp/demo/as.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(maptree)
#options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 2: 
###################################################
exp2d.data <- exp2d.rand(lh=0, dopt=10)
X <- exp2d.data$X
Z <- exp2d.data$Z
Xcand <- lhs(1000, rbind(c(-2,6),c(-2,6)))


###################################################
### chunk number 3: 
###################################################
exp1 <- btgpllm(X=X, Z=Z, pred.n=FALSE, corr="exp", verb=0)


###################################################
### chunk number 4: mapt
###################################################
tgp.trees(exp1)


###################################################
### chunk number 5: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()


###################################################
### chunk number 6: 
###################################################
XX <- tgp.design(200, Xcand, exp1)
XX <- rbind(XX, c(-sqrt(1/2),0))


###################################################
### chunk number 7: cands
###################################################
plot(exp1$X, pch=19, cex=0.5)
points(XX)
mapT(exp1, add=TRUE)


###################################################
### chunk number 8: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()


###################################################
### chunk number 9: 
###################################################
exp.as <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", improv=TRUE, 
                        Ds2x=TRUE, verb=0)


###################################################
### chunk number 10: expas
###################################################
par(mfrow=c(1,3), bty="n")
plot(exp.as, main="tgpllm,", layout="as", as="alm")
plot(exp.as, main="tgpllm,", layout='as', as='alc')
plot(exp.as, main="tgpllm,", layout='as', as='improv')


###################################################
### chunk number 11: 
###################################################
rl <- readline("press RETURN to continue: ")
graphics.off()
